@@ -1,7 +1,7 @@
 /*
  * bekijk.c 1.4.0
  *
- * Copyright (C) 1997,98,2000-03 Staf Wagemakers Belgie/Belgium
+ * Copyright (C) 1997, 1998, 2000, 2001, 2002, 2003, 2006, 2007  Staf Wagemakers Belgium
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -21,9 +21,8 @@
 
 #define TAB 9
 #define TYPE_WIDTH 59
-#include "config.h"
-#include <ncurses.h>
-#include <string.h>
+#include "common.h"
+#include"ncurses_h.h"
 #include <signal.h>
 #include <errno.h>
 #include <unistd.h>
@@ -45,7 +44,6 @@
 #include "view.h"
 #include "configfile.h"
 #include "lookat_configfile.h"
-#include "xmalloc.h"
 #include "outofmemory.h"
 #include "msg.h"
 #include "color.h"
@@ -213,7 +211,8 @@ void open_hlpm (MENU *m)
 /* ----------------------------------------- */
 void open_fg (MENU *m)
 {
-   m->w=open_win(m->amount+2,m->l+2,2*(m->parent)->sel+9,37);
+   /* m->w=open_win(m->amount+2,m->l+2,2*(m->parent)->sel+9,37); */
+   m->w=open_win(m->amount+2,m->l+2,2*(m->parent)->sel+LINES/2-3,COLS/2-3);
    m_open(m,setcolors_w);
 }
 
@@ -235,12 +234,11 @@ int exit_lookat(WINDOW *rw) {
 /* ----------------------------------------- */
 int open_best(int mode)
 {
-   int i;
    char *vb;
-   void *ends=NULL;
+   int (*ends)(WINDOW *)=NULL;
    chtype kl[4]={kleur[9],kleur[10],kleur[11],kleur[12]};
    vb=bv.filename;
-   if(mode) ends=exit_lookat;
+   if(mode) ends=&exit_lookat;
 
    bv.filename=open_filewin(win2,txt_bo,kl,win1,ends);
    if (bv.filename) {
@@ -281,7 +279,7 @@ int open_zoek_venster (char *titel,char *tekst)
    int brol;
    int ret=0;
    int toetsen[]={27,9,0};
-   int pl_ok[]={4,7,4,26,6,15,6,35};
+   unsigned pl_ok[]={4,7,4,26,6,15,6,35};
    int key_m[]={0,9,'\n',' ','\n','\n'};
    w=open_cwin(8,60);
    m.w=w;
@@ -546,7 +544,7 @@ void zoek_tekst (char mode)
 /* -------------------------------------------- */
 /* Funktie om naar de lijnnr. te gaan ...       */
 /* -------------------------------------------- */
-ga_lijn ()
+void ga_lijn ()
 {
    MENU m;
    int brol;
@@ -563,7 +561,7 @@ ga_lijn ()
    brol=open_inputwin(7,60,&m,kleur[16],&s,txt,1,win1);
    curs_set(0);
    if (strlen(s.c)&&!brol) {
-      sscanf(s.c,"%d",&y);
+      sscanf(s.c,"%ld",&y);
       if (y) --y;
         else bv.y=0;
       view_sety(y);
@@ -576,10 +574,9 @@ ga_lijn ()
 /* Bijvoegen van een type ...                   */
 /* -------------------------------------------- */
 
-add_type (int *n,char *name,char *val)
+void add_type (int *n,char *name,char *val)
 {
    int i,max;
-   char ***ccc;
    i=0;
    while(bv.view_exec[i]!=NULL) ++i;
    max=i+1;
@@ -603,7 +600,7 @@ add_type (int *n,char *name,char *val)
 /* mode	       = 0 -> bijvoegen			*/
 /*		 1 -> aanpassen			*/
 /* --------------------------------------------	*/
-int open_type_venster (char *titel,char *txt_typename,char *txt_typeval,int n,int mode)
+void open_type_venster (char *titel,char *txt_typename,char *txt_typeval,int n,int mode)
 {
    WINDOW *w;
    MENU m;
@@ -611,7 +608,7 @@ int open_type_venster (char *titel,char *txt_typename,char *txt_typeval,int n,in
    char ***ccc;
    int brol;
    int toetsen[]={27,9,0};
-   int pl_ok[]={7,11,7,31};
+   unsigned pl_ok[]={7,11,7,31};
    int key_m[]={0,9,'\n',' ','\n',27};
    w=open_cwin(10,50);
    ccc=bv.view_exec;
@@ -707,7 +704,7 @@ int open_type_venster (char *titel,char *txt_typename,char *txt_typeval,int n,in
 /* wissen van een type ...                      */
 /* -------------------------------------------- */
 
-delete_type(int *n)
+void delete_type(unsigned *n)
 {
 int i;
 xfree(bv.view_exec[*n][1]);
@@ -787,19 +784,17 @@ cc=NULL;
 /* -------------------------------------------- */
 /* Funktie voor types...                        */
 /* -------------------------------------------- */
-set_types ()
+void set_types ()
 {
 MENU m,mm;
 WINDOW *w;
 int key_m[]={KEY_UP,KEY_DOWN,'\n',KEY_PPAGE,KEY_NPAGE,27,9};
 int key_mm[]={0,9,'\n',' ',27,'\n'};
-int pl_m[]={2,5,3,5,4,5,5,5,6,5,7,5,8,5,9,5,10,5,11,5,12,5,13,5,14,5};
-int pl_mm[]={15,1,15,1,15,1,15,1,15,1,2,5};
+unsigned pl_m[]={2,5,3,5,4,5,5,5,6,5,7,5,8,5,9,5,10,5,11,5,12,5,13,5,14,5};
+unsigned pl_mm[]={15,1,15,1,15,1,15,1,15,1,2,5};
 int m_selected=0;
 int s,i,brol=0;
-char ***ccc=NULL;
 char **cc=NULL;
-char *c=NULL;
 unsigned u=0;
 i=(TYPE_WIDTH+11-strlen(txt_typem[0])-strlen(txt_typem[1])-strlen(txt_typem[2])-strlen(txt_typem[3])-strlen(txt_typem[4]))/6;
 pl_mm[1]=1+i;
@@ -814,7 +809,8 @@ m.color3=kleur[13];
 m.place=pl_m;
 m.key=key_m;
 m.l=TYPE_WIDTH;
-m.hkey=m.hplace=NULL;
+m.hkey=NULL;
+m.hplace=NULL;
 w=open_cwin(18,TYPE_WIDTH+10);
 m.w=w;
 m.used=m.sel=0;
@@ -958,7 +954,7 @@ void init_colors (struct color *colors) {
 
 }
 
-set_main_colors() {
+void set_main_colors() {
 	wbkgdset(bv.win,kleur[2]);
        	wbkgdset(win2,kleur[8]);
         wbkgdset(hm_win,kleur[4]);
@@ -987,11 +983,11 @@ void refresh_setcolors_win(WINDOW *w)
 
 }
 
-open_color_venster(MENU *setcolors_m, struct color *colors,int p) {
+void open_color_venster(MENU *setcolors_m, struct color *colors,int p) {
 
-  int pl_cm_color[]={2,5,4,5,6,5,8,5,8,19,8,33};
-  int pl_cm_mono[]={2,5,4,5,8,5,8,19,8,33};
-  int pl_sc[]={1,1,2,1,3,1,4,1,5,1,6,1,7,1,8,1};
+  unsigned pl_cm_color[]={2,5,4,5,6,5,8,5,8,19,8,33};
+  unsigned pl_cm_mono[]={2,5,4,5,8,5,8,19,8,33};
+  unsigned pl_sc[]={1,1,2,1,3,1,4,1,5,1,6,1,7,1,8,1};
   int key_cm[]={0,9,'\n',0,0,27};
   int key_sub[]={KEY_UP,KEY_DOWN,'\n',0,0,27};
   int x,y;
@@ -1008,7 +1004,7 @@ open_color_venster(MENU *setcolors_m, struct color *colors,int p) {
   cp_color(&backup_color,&colors[p]);
 
   /* cm.w init */
-  
+ 
   cm.w=open_cwin(10,48);
   leaveok(cm.w,TRUE);
   curs_set(0);
@@ -1201,7 +1197,7 @@ open_color_venster(MENU *setcolors_m, struct color *colors,int p) {
 /* -------------------------------------------- */
 /* Funktie voor de kleuren...                   */
 /* -------------------------------------------- */
-set_colors ()
+void set_colors ()
 {
 
    MENU m,mm;
@@ -1209,12 +1205,10 @@ set_colors ()
    WINDOW *w;
    int key_m[]={KEY_UP,KEY_DOWN,'\n',KEY_PPAGE,KEY_NPAGE,27,9};
    int key_mm[]={0,9,'\n',' ',27,'\n'};
-   int pl_m[]={2,5,3,5,4,5,5,5,6,5,7,5,8,5,9,5,10,5,11,5,12,5,13,5,14,5};
-   int pl_mm[]={2,27,4,27,6,27,2,5};
+   unsigned pl_m[]={2,5,3,5,4,5,5,5,6,5,7,5,8,5,9,5,10,5,11,5,12,5,13,5,14,5};
+   unsigned pl_mm[]={2,27,4,27,6,27,2,5};
    int s,i,brol=0;
-   char ***ccc=NULL;
    char **cc=NULL;
-   char *c=NULL;
    unsigned u=0;
    struct color *backup_colors;
 
@@ -1228,7 +1222,8 @@ set_colors ()
    m.place=pl_m;
    m.key=key_m;
    m.l=18;
-   m.hkey=m.hplace=NULL;
+   m.hkey=NULL;
+   m.hplace=NULL;
 
    w=open_cwin(15,42);
    setcolors_w=m.w=w;
@@ -1362,19 +1357,20 @@ return (fp);
 /* ---------------------------------------------------- */ 
 /* Hoofdprg ...						*/
 /* ---------------------------------------------------- */ 
-main(int arg1,char *arg2[])
+int main(int arg1,char *arg2[])
 {
-VIEW_PAR *vp;
-struct view_exec *exec;
-int i,ii,c;
+int i,c;
+int prev_lines=0;
+int prev_cols=0;
+
 WINDOW *sub_win;
 char **cp,*sp;
-int  pl_hm[]={0,1,0,9,0,12,0,15,0,17};
-int  pl_bm[]={1,1,3,1,5,1};
-int  pl_gm[]={1,1,2,1,3,1,4,1,5,1,};
-int  pl_zm[]={1,1,2,1,3,1,};
-int  pl_om[]={1,1,2,1,4,1,5,1,7,1};
-int  pl_hlpm[]={1,1,2,1,3,1,};
+unsigned  pl_hm[]={0,1,0,9,0,12,0,15,0,17};
+unsigned  pl_bm[]={1,1,3,1,5,1};
+unsigned  pl_gm[]={1,1,2,1,3,1,4,1,5,1,};
+unsigned  pl_zm[]={1,1,2,1,3,1,};
+unsigned  pl_om[]={1,1,2,1,4,1,5,1,7,1};
+unsigned  pl_hlpm[]={1,1,2,1,3,1,};
 int key_sub[]={KEY_UP,KEY_DOWN,'\n',KEY_LEFT,KEY_RIGHT,27};
 int key_hm[]={KEY_LEFT,KEY_RIGHT,'\n',KEY_UP,KEY_DOWN,27};
 MENU hm,bm,gm,zm,om,hlpm;
@@ -1413,6 +1409,11 @@ if ((fp=get_config_file("r"))==NULL) bv.mode=0;
 	    bv.view_exec[tt]=type;
 	    ++tt;
           }
+	  else {
+
+		free_string_array(type);
+
+	  }
     } 
     bv.view_exec=xrealloc(bv.view_exec,sizeof(char ***)*(tt+1));
     bv.view_exec[tt]=NULL; 
@@ -1432,6 +1433,13 @@ if (!(initscr())) {
 
 set_memerr(outofmemory);
 
+/*
+ * Store the LINES and COLS for resize detect
+ */
+
+prev_lines=LINES;
+prev_cols=COLS;
+
 bv.lines=LINES-2;
 bv.cols=COLS;
 bv.sx=bv.sy=0;
@@ -1699,7 +1707,16 @@ do {
    touchwin(win2);
    wrefresh(win2);
    wrefresh(win1);
-   c=wgetch(win1);
+
+   if ( prev_cols != COLS && prev_lines != LINES ) {
+
+	   	c='r';
+
+   }
+   else {
+   		c=wgetch(win1);
+
+   }
    if ((c==KEY_F(9))||(c==27)) {
       int m_sel=0;
       if (c==27) {
@@ -1910,10 +1927,64 @@ do {
 		     open_best(0);
 		     cp=bv.file;bv.x=0;s[0]=0;
 		     break;
+    case KEY_RESIZE:
     case 12       :
     case 'R'      : 
-    case 'r'      :  wrefresh(curscr);
-	             break;
+    case 'r'      : {
+
+		     	int current_y=view_gety()-1;
+
+		        /*
+			 * Reinit hm_win and hm_menu
+			 */
+
+			wresize(hm_win,1,COLS);
+			werase(hm_win);
+			pl_hm[9]=COLS-strlen(txt_hm[3])-2;
+			menu_print(&hm);
+			touchwin(hm_win);
+			wrefresh(hm_win);
+
+			/* 
+			 * Reinit win2
+			 */
+
+			wresize(win2,1,COLS);
+			mvwin(win2,LINES-1,0);
+			werase(win2);
+			touchwin(win2);
+			wrefresh(win2);
+
+			/*
+			 * Reinit & Refresh view
+			 */
+
+			wresize(win1,LINES-2,COLS);
+			werase(win1);
+
+			bv.lines=LINES-2;
+			bv.cols=COLS;
+			view_refresh();
+
+			view_sety(current_y);
+
+			view_refresh();
+
+			/*
+			 * refresh curscr
+			 */
+
+		     	wrefresh(curscr);
+
+			/*
+			 * reset previous COLS and LINES
+			 */
+
+			prev_cols=COLS;
+			prev_lines=LINES;
+
+		   }
+	             	break;
     case 'h'      :
     case 'H'      :
     case '?'      :
@@ -1934,6 +2005,8 @@ do {
     }
    } while ((c!='Q')&&(c!='q')&&(c!=27)&&(c!=KEY_F(10)));
 } while (!exit_lookat(win1));
+
+
 view_free();
 touchwin(win1);
 touchwin(win2);
@@ -1943,5 +2016,7 @@ delwin(win1);
 delwin(win2);
 endwin();
 
+exit(0);
+
 }
 
