@@ -19,7 +19,7 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. */
 /* Written by Jan Brittenson, bson@gnu.ai.mit.edu.  */
 
 //#if HAVE_CONFIG_H
-//# include <config.h>
+# include <config.h>
 //#endif
 
 /* Specification.  */
@@ -45,6 +45,8 @@ getline (lineptr, n, stream)
 }
 
 #else /* ! have getdelim */
+int
+getdelim (lineptr, n, delimiter, stream);
 
 # include <assert.h>
 
