@@ -14,8 +14,10 @@ You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
 Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
 
+#include "config.h"
 #ifndef GETLINE_H_
 # define GETLINE_H_ 1
+# define __USE_GNU 1
 
 # include <stddef.h>
 # include <stdio.h>
