@@ -1,7 +1,7 @@
 /*
  *  view.h
  *
- *  Copyright (C) 1997,98  Staf Wagemakers Belgie/Belgium
+ *  Copyright (C) 1997, 1998, 2006  Staf Wagemakers Belgie/Belgium
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,10 @@
 
 #ifndef __VIEW_H
 #include "config.h"
+#include "common.h"
+#include "xstring.h"
 #include "win.h"
+#include "getline.h"
 #define TAB 9
 typedef struct 
 {
